| Home | Libraries | People | FAQ | More

## Examples

An Optimized Version of std::copy
An Optimised Version of std::fill
An Example that Omits Destructor Calls For Types with Trivial Destructors
An improved Version of std::iter_swap
Convert Numeric Types and Enums to double
Improving std::min with common_type

| Copyright © 2000, 2011 Adobe Systems Inc, David Abrahams, Frederic Bron, Steve Cleary, Beman Dawes, Aleksey Gurtovoy, Howard Hinnant, Jesse Jones, Mat Marcus, Itay Maman, John Maddock, Alexander Nasonov, Thorsten Ottosen, Roman Perepelitsa, Robert Ramey, Jeremy Siek, Robert Stewart and Steven Watanabe Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)